# Copyright (c) 2014 Dave Love, Liverpool University
# The licence for this file is as for the package itself.

%bcond_without mpich

Name:		mpiP
Version:	3.4.1
Release:	4%{?dist}
Summary:	Lightweight profiling library for MPI applications

#Group:		
License:	BSD
URL:		http://mpip.sourceforge.net/
Source0:	http://downloads.sourceforge.net/project/mpip/mpiP/mpiP-3.4/mpiP-%version.tar.gz

BuildRequires:	openmpi-devel, libunwind-devel, binutils-devel
BuildRequires:	pnmpi-openmpi-devel
%if %{with mpich}
BuildRequires:	mpich-devel pnmpi-mpich-devel
%endif
BuildRequires:	gcc-gfortran, gcc-c++
BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

%global desc \
mpiP is a lightweight profiling library for MPI applications.  Because\
it only collects statistical information about MPI functions, mpiP\
generates considerably less overhead and much less data than tracing\
tools.  All the information captured by mpiP is task-local.  It only\
uses communication during report generation, typically at the end of\
the experiment, to merge results from all of the tasks into one output\
file.

%description
%desc

%package openmpi
Summary:	Lightweight profiling library for MPI applications (openmpi)
Requires:	openmpi

%description openmpi
%desc

This is the openmpi version.

%package mpich
Summary:	Lightweight profiling library for MPI applications (mpich)
Requires:	mpich

%description mpich
%desc

This is the openmpi version.

%prep
%setup -q


%build
mkdir -p openmpi mpich
%global _configure ../configure

pushd openmpi
%_openmpi_load
%configure --with-clock_gettime --libdir=$MPI_LIB CPPFLAGS=-I. LDFLAGS=-lpnmpi
make %{?_smp_mflags} shared
make %{?_smp_mflags}
%_openmpi_unload
popd

%if %{with mpich}
pushd mpich
%_mpich_load
%configure --with-clock_gettime --libdir=$MPI_LIB CPPFLAGS=-I. LDFLAGS=-lpnmpi
make %{?_smp_mflags} shared
make %{?_smp_mflags}
%_mpich_unload
popd
%endif


%install
rm -rf $RPM_BUILD_ROOT
ln -s ../doc openmpi
ln -s ../doc mpich
%_openmpi_load
mkdir -p $RPM_BUILD_ROOT$MPI_LIB/pnmpi-modules
make -C openmpi install DESTDIR=$RPM_BUILD_ROOT
pnmpi-patch $RPM_BUILD_ROOT$MPI_LIB/libmpiP.so $RPM_BUILD_ROOT$MPI_LIB/pnmpi-modules/libmpiP.so
%_openmpi_unload
%if %{with mpich}
%_mpich_load
mkdir -p $RPM_BUILD_ROOT$MPI_LIB/pnmpi-modules
make -C mpich install DESTDIR=$RPM_BUILD_ROOT
pnmpi-patch $RPM_BUILD_ROOT$MPI_LIB/libmpiP.so $RPM_BUILD_ROOT$MPI_LIB/pnmpi-modules/libmpiP.so
%_mpich_unload
%endif
rm -rf $RPM_BUILD_ROOT%_datadir/doc
rm $RPM_BUILD_ROOT%_libdir/*/lib/*.a


%clean
rm -rf $RPM_BUILD_ROOT


%files openmpi
%doc doc/UserGuide* doc/README ChangeLog
%_libdir/openmpi/lib/*
%dir %_libdir/openmpi/lib/pnmpi-modules
%_libdir/openmpi/lib/pnmpi-modules/*

%if %{with mpich}
%files mpich
%doc doc/UserGuide* doc/README ChangeLog
%_libdir/mpich/lib/*
%dir %_libdir/mpich/lib/pnmpi-modules
%_libdir/mpich/lib/pnmpi-modules/*
%endif


%changelog
* Sat Sep 26 2015 Dave Love <loveshack@fedoraproject.org> - 3.4.1-4
- Link against libpnmpi

* Mon Jan 12 2015 Dave Love <d.love@liverpool.ac.uk> - 3.4.1-3
- Install pnmpi module

* Fri Oct 24 2014 Dave Love <d.love@liverpool.ac.uk> - 3.4.1-2
- Use clock_gettime -- openmpi's mpi_wtime uses gettimeofday

* Wed Jul  2 2014 Dave Love <d.love@liverpool.ac.uk> - 3.4.1-1
- Update to 3.4.1

* Fri Jun 20 2014 Dave Love <d.love@liverpool.ac.uk> - 3.4-2
- Make openmpi and mpich packages

* Thu Feb 20 2014 Dave Love <d.love@liverpool.ac.uk> - 3.4-1
- Initial packaging
